@@ -26,7 +26,7 @@ class MCDA:
         self.df_weighted = 0
         self.df_decision = []
 
-    def dataframe(self, alt_data, alt_labels=[], criteria_labels=[]):
+    def dataframe(self, alt_data, alt_labels=None, criteria_labels=None):
         """
         Set data for MCDM problem and save it into attribute: df_original.
         
@@ -43,24 +43,28 @@ class MCDA:
         :rtype: none
         """
 
-        # define state labels if not exists
-        if criteria_labels == []:
-            for s in range(0, len(alt_data[0])):
-                criteria_labels.append("C" + str(s+1))
+        # define criteria labels if not exists
+        if criteria_labels is None:
+            criteria_labels = []
+            for s in range(1, len(alt_data[0])+1):
+                criteria_labels.append("C" + str(s))
 
         # define alternative labels if not exists
-        if alt_labels == []:
-            for a in range(0, len(alt_data)):
-                alt_labels.append("A" + str(a+1))
+        if alt_labels is None:
+            alt_labels = []
+            for a in range(1, len(alt_data)+1):
+                alt_labels.append("A" + str(a))
+
+        
 
         df_data = pd.DataFrame(data=alt_data, columns=criteria_labels)
         df_data.insert(loc=0,
                     column='alternatives',
                     value=alt_labels)
-        dfo = copy.deepcopy(df_data)
+        dfo = df_data
 
-        self.df_original = copy.deepcopy(dfo)
-        self.df_calc = copy.deepcopy(dfo)
+        self.df_original = copy.copy(dfo)
+        self.df_calc = copy.copy(dfo)
         self.decision = []
 
     def set_weights_manually(self, weights, free=False):
